@@ -5,7 +5,7 @@ use strict;
 use vars qw( $VERSION $HTML_RENDER_CLASS $HTML_EXTENSION
  $CSS $JAVASCRIPT $SLEEPY $SEARCH_CLASS @ISA
 );
-$VERSION = '3.14';
+$VERSION = '3.15';
 @ISA = ();  # Yup, we're NOT a subclass of Pod::Simple::HTML!
 
 # TODO: nocontents stylesheets. Strike some of the color variations?
@@ -726,7 +726,7 @@ sub _gen_css_wad {
       'whtgrng', # white_with_green_on_grey
       'grygrnw', # grey_with_green_on_white
   ) {
-    my $outname = "$variation\_";
+    my $outname = $variation;
     my $this_css = join "\n",
       "/* This file is autogenerated.  Do not edit.  $outname */\n",
       "\@import url(\"./_$variation.css\");",
@@ -735,7 +735,7 @@ sub _gen_css_wad {
     ;
     my $name = $outname;    
     $name =~ tr/-_/  /;
-    $self->add_css( "$outname.css", 0, $name, 0, 0, \$this_css);
+    $self->add_css( "_$outname.css", 0, $name, 0, 0, \$this_css);
   }
 
   return;
